@@ -10,9 +10,7 @@ fn should_return_err_when_file_is_already_locked() {
     let guard = try_lock(&path);
     assert_that(&guard).is_ok();
 
-    assert_that(&try_lock(&path))
-        .is_err()
-        .matches(|e| e.kind() == ErrorKind::WouldBlock);
+    assert_that(&try_lock(&path)).is_err();
 }
 
 #[test]
